@@ -82,5 +82,5 @@ class AccountResource(Resource):
     def list(self, params: Optional[AccountListOpts] = None) -> List[Account]:
         return super(AccountResource, self)._list(params)
 
-    def create(self, opts: AccountCreateOpts, request_opts: Optional[RequestOpts]) -> Account:
+    def create(self, opts: AccountCreateOpts, request_opts: Optional[RequestOpts] = None) -> Account:
         return super(AccountResource, self)._create(opts, request_opts)
