@@ -102,7 +102,7 @@ class EntityResource(Resource):
     def __init__(self, config: Configuration):
         super(EntityResource, self).__init__(config.add_path('entities'))
 
-    def create(self, opts: EntityCreateOpts, request_opts: Optional[RequestOpts]) -> Entity:
+    def create(self, opts: EntityCreateOpts, request_opts: Optional[RequestOpts] = None) -> Entity:
         return super(EntityResource, self)._create(opts, request_opts)
 
     def update(self, _id: str, opts: EntityCreateOpts) -> Entity:
